Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Endpoints

OAuth2 / OIDC

EndpointDescription
GET /.well-known/openid-configurationOIDC Discovery
GET /.well-known/jwks.jsonJSON Web Key Set
GET /authorizeAuthorization endpoint (login page)
POST /tokenToken endpoint
GET/POST /userinfoUserInfo endpoint
POST /introspectToken Introspection (RFC 7662)
POST /revokeToken Revocation (RFC 7009)
GET/POST /logoutOIDC End Session / Logout
POST /device_authorizationDevice Authorization (RFC 8628)
GET/POST /deviceDevice verification page

curl examples for every grant are in Requesting tokens.

SAML

EndpointDescription
GET /saml/metadataIdP Metadata
GET/POST /saml/ssoSingle Sign-On (supports both HTTP-POST and HTTP-Redirect bindings)
POST /saml/attribute-queryAttribute Query

Bindings, strict-binding mode, response signing, and canonicalization are covered in SAML options.

REST API

EndpointDescription
GET /api/healthHealth check
GET /api/usersList users
GET /api/users/{username}Get user details
POST /api/users/{username}/tokenGenerate token
GET /api/auditGet audit log
POST /api/config/reloadReload configuration
POST /api/keys/rotateRotate cryptographic keys
GET /api/keys/infoGet key information